/**
    An implementation of this interface will specify a way to compare two objects from a particular class. This interface is defined in a "generic" way, so all references declared in this interface are of type Object. In an implementation, in order to do any real comparing, all of the paramters below will need to be cast to whatever type that the implementation is expecting.
    <p>
    Notice that it is possible, and in some cases might even be desirable, that an implementation of this interface could be defined to compare objects from one class with objects from a different class (for example, it might be needed to compare a certain String field in an object of one type, with an String field from an object of a different type). So all of the parameters called item1 below could actually be implemented as one type and all of the parameters called item2 could be implemented as a different type.
*/

public interface Comparer
{
   /**
       This method determines if the two objects are comparable with respect to the specific way this Comparer is implemented. Usually, this method will use the <code>instanceof</code> operator to check that the types of the two parameters are what is expected by the comparing methods.
   */
   boolean isComparable(Object item1, Object item2);

   /**
       Determines if the objects are "equal" relative to the way that this Comparator is being implemented.
   */
   boolean isEqual(Object item1, Object item2);

   /**
      Determines the order of the objects relative to the way that this Comparator is being implemented.
   */
   boolean isLessThan(Object item1, Object item2);

   /**
      Determines the order of the objects relative to the way that this Comparator is being implemented.
   */
   boolean isLessThanOrEqual(Object item1, Object item2);

   /**
      Determines the order of the objects relative to the way that this Comparator is being implemented.
   */
   boolean isGreaterThan(Object item1, Object item2);

   /**
      Determines the order of the objects relative to the way that this Comparator is being implemented.
   */
   boolean isGreaterThanOrEqual(Object item1, Object item2);
}